==> BlueAutomata-0.3.tar.gz: BlueAutomata-0.3/setup.py <==
from distutils.core import setup
setup(
  name = 'BlueAutomata',         # How you named your package folder (MyLib)
  packages = ['BlueAutomata'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A package to ease the workflow for reporting in a company',   # Give a short description about your library
  author = 'keanteng',                   # Type in your name
  author_email = 'u2004763@siswa.um.edu.my',      # Type in your E-Mail
  url = 'https://github.com/keanteng/blueautomata',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/keanteng/blueautomata/archive/refs/tags/v_0.3.tar.gz',    # I explain this later on
  keywords = ['automation', 'vba', 'reporting', 'automate'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          #'pandas',
          #'win32com.client',
          #'fuzzywuzzy',
          #'python-Levenshtein',
      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.11',      #Specify which pyhton versions that you want to support
  ],
)

==> BlueAutomata-0.4.tar.gz: BlueAutomata-0.4/setup.py <==
from distutils.core import setup
setup(
  name = 'BlueAutomata',         # How you named your package folder (MyLib)
  packages = ['BlueAutomata'],   # Chose the same as "name"
  version = '0.4',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A package to ease the workflow for reporting in a company',   # Give a short description about your library
  author = 'keanteng',                   # Type in your name
  author_email = 'u2004763@siswa.um.edu.my',      # Type in your E-Mail
  url = 'https://github.com/keanteng/blueautomata',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/keanteng/blueautomata/archive/refs/tags/v_0.4.tar.gz',    # I explain this later on
  keywords = ['automation', 'vba', 'reporting', 'automate'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'win32com.client',
          'fuzzywuzzy',
          'python-Levenshtein',
      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.11',      #Specify which pyhton versions that you want to support
  ],
)
